@@ -8,10 +8,9 @@ use Class::Accessor::Lite;
 use Cwd;
 use DBI;
 use File::Temp qw(tempdir);
-use Time::HiRes qw(nanosleep);
 use POSIX qw(SIGTERM SIGKILL WNOHANG setuid);
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 # Various paths that Postgres gets installed under, sometimes with a version on the end,
 # in which case take the highest version. We append /bin/ and so forth to the path later.
@@ -23,7 +22,7 @@ our @SEARCH_PATHS = (
     # ubuntu (maybe debian as well, find the newest version)
     (sort { $b cmp $a } grep { -d $_ } glob "/usr/lib/postgresql/*"),
     # macport
-    (sort { $b cmp $a } grep { -d $_ } glob "/opt/local/lib/postgresql-*"),
+    (sort { $b cmp $a } grep { -d $_ } glob "/opt/local/lib/postgresql*"),
     # Postgresapp.com
     (sort { $b cmp $a } grep { -d $_ } glob "/Applications/Postgres.app/Contents/Versions/*"),
     # BSDs end up with it in /usr/local/bin which doesn't appear to be in the path sometimes:
@@ -47,7 +46,7 @@ our %Defaults = (
     pid             => undef,
     port            => undef,
     postmaster      => undef,
-    postmaster_args => '-h 127.0.0.1',
+    postmaster_args => '-h 127.0.0.1 -F',
     uid             => undef,
     _owner_pid      => undef,
 );
@@ -104,17 +103,26 @@ sub DESTROY {
 }
 
 sub dsn {
+    my $self = shift;
+    my %args = $self->_default_args(@_);
+
+    return 'DBI:Pg:' . join(';', map { "$_=$args{$_}" } sort keys %args);
+}
+
+sub _default_args {
     my ($self, %args) = @_;
     $args{host} ||= '127.0.0.1';
     $args{port} ||= $self->port;
     $args{user} ||= 'postgres';
     $args{dbname} ||= 'test';
-    return 'DBI:Pg:' . join(';', map { "$_=$args{$_}" } sort keys %args);
+    return %args;
 }
 
 sub uri {
-    my ($self, %args) = @_;
-    return sprintf('postgresql://postgres@127.0.0.1:%d/test', $self->port);
+    my $self = shift;
+    my %args = $self->_default_args(@_);
+
+    return sprintf('postgresql://%s@%s:%d/%s', @args{qw/user host port dbname/});
 }
 
 sub start {
@@ -227,17 +235,17 @@ sub stop {
     $sig ||= SIGTERM;
 
     kill $sig, $self->pid;
-    my $timeout = 10 * 1000000000;
+    my $timeout = 10;
     while ($timeout > 0 and waitpid($self->pid, WNOHANG) <= 0) {
-        $timeout -= nanosleep(500000000);
+        $timeout -= sleep(1);
     }
 
     if ($timeout <= 0) {
         warn "Pg refused to die gracefully; killing it violently.\n";
         kill SIGKILL, $self->pid;
-        $timeout = 5 * 1000000000;
+        $timeout = 5;
         while ($timeout > 0 and waitpid($self->pid, WNOHANG) <= 0) {
-            $timeout -= nanosleep(500000000);
+            $timeout -= sleep(1);
         }
         if ($timeout <= 0) {
             warn "Pg really didn't die.. WTF?\n";
@@ -397,6 +405,13 @@ Arguments passed to C<initdb> and C<postmaster>.  Following example adds
 Builds and returns dsn by using given parameters (if any).  Default username is
 'postgres', and dbname is 'test' (an empty database).
 
+=head2 uri
+
+Builds and returns a connection URI using the given parameters (if any). See
+L<URI::db> for details about the format.
+
+Default username is 'postgres', and dbname is 'test' (an empty database).
+
 =head2 pid
 
 Returns process id of PostgreSQL (or undef if not running).
